@@ -3,7 +3,7 @@
 from pkg import __version__
 import argparse
 
-from .start import start_code
+from .start import start_code, spider
 
 
 def get_version():
@@ -38,6 +38,9 @@ def main():
         start_code(start)
         print("完成", start)
 
+    if url:
+        spider(url)
+
 
 if __name__ == "__main__":
     main()
