@@ -1,4 +1,5 @@
 import os
+from PrSpider import PrSpiders
 
 code_str = """from PrSpider import PrSpiders
 
@@ -21,3 +22,16 @@ def start_code(name):
     print(code_path)
     with open(code_path, mode="w", encoding="utf-8") as f:
         f.write(code_str)
+
+
+class spider(PrSpiders):
+    def __init__(self, url):
+        self.url = url
+        super().__init__()
+
+    def start_requests(self, **kwargs):
+        PrSpiders.Requests(url=self.url, callback=self.parse)
+
+    def parse(self, response):
+        print(response.text)
+        print(response)
